#
# spec file for package snd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifarch aarch64
%define _lto_cflags %{nil}
%endif

%ifarch %{ix86} x86_64 %{ppc} ppc64 ppc64le
# The jack support has some inline assembly, but only for x86/ppc
%bcond_without jack
%else
%bcond_with jack
%endif
Name:           snd
Version:        24.5
Release:        2.3
Summary:        Sound File Editor
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://ccrma.stanford.edu/software/snd/
Source:         ftp://ccrma-ftp.stanford.edu/pub/Lisp/snd-%{version}.tar.gz
Source1:        snd.desktop.in
Source2:        snd.png
BuildRequires:  alsa-devel
BuildRequires:  fftw3-devel
BuildRequires:  freeglut-devel
BuildRequires:  gsl
BuildRequires:  gsl-devel
BuildRequires:  gtk3-devel
BuildRequires:  ladspa-devel
BuildRequires:  libXpm-devel
BuildRequires:  libdrm-devel
BuildRequires:  libjack-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  motif-devel
BuildRequires:  translate-suse-desktop
Requires:       ladspa

%description
Snd is a sound editor modelled loosely after Emacs and an old,
PDP-10 sound editor named Dpysnd. It can accommodate any
number of sounds each with any number of channels and can be customized
and extended using guile and guile-gtk.

%prep
%setup -q
cp -a %{SOURCE1} .
find -name "*~" -type f -print -delete
find -name "*.png" -type f -exec chmod 0644 "{}" "+"

%build
%configure \
  --with-gui \
  --with-alsa \
  --with-ladspa \
  --with-gl \
  %{?with_jack:--with-jack} \
# feel free to improve following change and please notify upstream
sed -i "s:\(^LIBS =.*\):\1 -lX11 -ldl:" makefile
%make_build
%make_build sndplay sndinfo
%translate_suse_desktop snd.desktop

%install
install -d -m 755 %{buildroot}/%{_bindir}
for i in snd sndplay sndinfo ; do
  install -c -m 755 $i %{buildroot}/%{_bindir}
done
mkdir -p %{buildroot}/%{_libdir}/snd/scheme
cp -a *.scm %{buildroot}/%{_libdir}/snd/scheme
mkdir -p %{buildroot}/%{_mandir}/man1
install -c -m 0644 snd.1 %{buildroot}/%{_mandir}/man1
install -D -m 0644 snd.desktop %{buildroot}%{_datadir}/applications/snd.desktop
mkdir -p %{buildroot}/%{_datadir}/pixmaps
cp %{SOURCE2} %{buildroot}/%{_datadir}/pixmaps

%files
%license COPYING
%doc *.Snd *.html pix
%{_mandir}/man?/*
%{_bindir}/*
%{_libdir}/snd
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.png

%changelog
* Fri Sep  6 2024 Stanislav Brabec <sbrabec@suse.com>
- Migrate from deprecated %%suse_update_desktop_file to
  %%translate_suse_desktop. (boo#1158957)
* Thu Jul 25 2024 Dirk Müller <dmueller@suse.com>
- update to 24.5:
  * in s7, added (settable) symbol-initial-value (the #_...
    value)
  * changed invalid-escape-function to invalid-exit-
    function
  * new *s7* fields: symbol-quote?, symbol-printer, and
    make-function
  * added function-arglist in sublet, varlet and
    s7_load_with_environment, () is no longer an abbreviation for
    (rootlet)
* Thu May  9 2024 Dirk Müller <dmueller@suse.com>
- update to 24.3:
  * s7: format now always returns a string (where it used to
    return #f it now returns "")
  * sam.c: bugfixes and improvements thanks to David Jaffe
  * checked: sbcl 2.4.3
* Sat Jan 27 2024 Dirk Müller <dmueller@suse.com>
- update to 24.0:
  * in s7, fixed various bugs, made a few more optimizations.
  * checked: sbcl 2.3.11, sbcl 2.4.0
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 23.9:
  * s7: added optional let argument to immutable? and immutable!
  * finally added error checks to the tree-* functions
  * ' (apostrophe) now is (#_quote ...) and similarly
    for the quasiquote helpers, apply-values, and list-
    values.
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 23.8:
  * s7: error handling, reader-cond, various (*s7* 'max-*) checks
  * checked: sbcl 2.3.9
* Mon Sep 11 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 23.7:
  * various small improvements and bugfixes in Snd and s7.
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 23.5:
  * s7: various small bugs and optimizations.
* Mon May 29 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 23.4 (no changelog).
* Wed May 10 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 23.3 (no changelog).
* Thu Dec 22 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 23.0 (no changelog)
* Thu Aug 20 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable LTO on aarch64 to fix build
* Mon Aug  3 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 20.6 (no changelog)
* Wed May 27 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 20.4
  * no changelog
* Thu Apr 16 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20.3:
  * No changelog available
- Small package cleanups
* Fri Mar 13 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 20.2 (no changelog)
* Fri Feb  7 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 20.1 (no changelog)
* Thu Jul 11 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 19.5 (no changelog provided)
- Remove snd-drop-date-time.diff, no longer required
- Drop snd-fix-no-return.diff, fixed upstream
- Reenable all archs, but without jack for anything but x86/ppc
  (32 and 64 bit), as it uses inline assembly
* Tue Apr 10 2018 jengelh@inai.de
- Ensure neutrality of descriptions.
- Replace old $RPM_* shell vars by macros.
- Favor find -exec over xargs.
* Wed Mar 28 2018 guillaume.gardet@opensuse.org
- Build only for x86* and ppc* since other archs are not supported
* Mon Feb  6 2017 tiwai@suse.de
- update to version 17.1:
  also fix the build on TW (boo#1023723)
- Drop obsoleted patch
  snd-15.5_backport_remove_glprofile.patch
- Fix no return value compile warnings:
  snd-fix-no-return.diff
- Avoid __DATE__ and __TIME__ usages (actually the code works fine
  but the BS detects it falsely, so better to drop the line):
  snd-drop-date-time.diff
* Sat Apr 18 2015 benoit.monin@gmx.fr
- update to version 15.5:
  * repl.scm to replace use of readline in various cases
- add snd-15.5_backport_remove_glprofile.patch:
  fix build with gtk 3.16
- drop sndrpmlintrc: hidden file not packaged anymore
* Wed Mar 25 2015 p.drouand@gmail.com
- Update to version 15.4
  * before-save-as-hook arg order changed, also new-sound, save-region,
    save-selection, save-sound-as
  * deprecated output-name-hook, info-popup-hook, peak-env-hook, start-hook
  * changed s7_new_type_x args
  * mus-audio* deprecated
  * mus_set_name (and mus-set-name) deprecated
  * sbcl support for gnuplot in dlocsig.lisp
- No information available about previous releases
- Replace gtk2-devel with gtk3-devel; build with gtk3 support
- Use download Url as source
- Remove obsolete %%clean and AUTHORS section
- Remove some obsolete stuff
- Do not try to build audinfo; dropped by upstream
- tutorial and Snd.ad have been dropped by upstream
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Wed Aug 31 2011 pgajdos@suse.com
- build with --no-copy-dt-needed-entries
* Sat Apr 10 2010 davejplater@gmail.com
- Fixed executable-stack rpmlint error in /usr/bin/snd
* Mon Apr  5 2010 davejplater@gmail.com
- Update to version 11.4. Fix broken Url: link. Binary sndrecord no
  longer exists. Added sndrpmlintrc for hidden file in tutorial.
* Mon Jul 27 2009 tiwai@suse.de
- updated to version 10.7:
  * default audio to ALSA
  * Some improvements in generators.scm, dlocsig.scm.
* Mon Apr 27 2009 tiwai@suse.de
- updated to version 10.5:
  * multidimensional and applicable vectors in s7.
  * pulseaudio support (not enabled yet)
  * moved the papoulis and dpss (slepian) fft-windows from
    dsp.scm to clm.c.  added sinc-window.
  * matlab mat-5 headers (for 1-channel sound data).
  * all hash literals using ',' changed to use '=>' in *.rb
  (for ruby 1.9.*) but ruby 1.9.n is not usable yet
  * With Kjetil's help, s7 is more than twice as fast now in s7test.
  * checked: mpfr 2.4.1, gtk 2.15.5|16.0|1, fftw 3.2.1, fth 1.2.3,
    sbcl 1.0.27
* Fri Jan 30 2009 tiwai@suse.de
- updated to version 10.3:
  * improvements to rt stuff
  * multiprecision math support
  * sox header support
  * jcvoi.scm
  * deprecated sine-emulation, etc
* Mon Nov 10 2008 tiwai@suse.de
- updated to version 10.1:
  * rhypars.cms addition
  * removed reader/writer locks in clm.c
* Wed Oct  1 2008 tiwai@suse.de
- updated to version 10.0:
  * rt/faust/stalin improvements
  * more generators
  * S7 support
  * others, see NEWS and HISTORY.Snd
- build JACK support only for x86 (for build fixes)
* Thu Apr 17 2008 tiwai@suse.de
- updated to version 9.8:
  * more rt improvements
  * clm4 updates
  * others, see NEWS
* Fri Jan 11 2008 tiwai@suse.de
- updated to version 9.6:
  * many Ruby improvements
  * fixed a help-system bug
  * 5 more generators in generators.scm
  * Open recent item in File menu
* Thu Jul 12 2007 tiwai@suse.de
- updated to version 9.2:
  * Forth/Ruby improvements
  * RIFF bugfix
  * fixes in snddiff.scm and examp.scm, green.scm
* Fri Jun  8 2007 tiwai@suse.de
- updated to version 9.1:
  * Two new hooks: peak-env-hook, draw-mix-hook
  * added mouse position args to mix-drag-hook
  * changes in background-gradient, sound-mark-info,
    mix-sync-max
  * moved equalize-panes to snd-motif.scm
* Wed May 23 2007 tiwai@suse.de
- updated to version 9.0:
  * removed mix-chans, mix-locked?, mix-inverted?, all track stuff
  track-colors.scm, mix-menu.scm
  * moved mix-properties into C.
  * added edit-properties, mix-sync.
  * spokenword.scm thanks to Ville Koskinen.
  * recorder dialog removed.
* Tue Apr 17 2007 tiwai@suse.de
- fix buildrequires ladspa -> ladspa-devel
* Tue Mar 27 2007 tiwai@suse.de
- update to version 8.9:
  * more fft windows
  * better noise reduction in clean.scm
  * added cairo graphics backend
* Mon Feb 12 2007 tiwai@suse.de
- update to version 8.8:
  * poussin-sum and jackson-sum in dsp.scm
  * changed default-output-data-format to mus-bfloat
  * removed initFile and the (undocumented) htmlDir X resources
  * added read/write support for Apple's new CAFF (64-bit) audio
    files
* Tue Jan  9 2007 tiwai@suse.de
- updated to version 8.7:
  * improvement in frame.scm
  * many *.fs and *.rb improvements
  * more to see NEWS and HISTORY.Snd
* Fri Oct 13 2006 aj@suse.de
- Add guile-devel to build requires.
* Thu Sep 21 2006 tiwai@suse.de
- updated to version 8.4:
  * many ruby, forth, and sndins-related improvements
  * improvements in some *.ins files
  * snd_frg.scm, display-bark-fft, def-optkey-instrument, etc.
* Wed Sep  6 2006 tiwai@suse.de
- updated to version 8.3:
  * Some additions to CLM generators
  * new scms: dlocsig.scm, green.scm, snd8.scm
  * g_signal and gtk_print_* to xg.c
  * merged new-icons.scm into new-buttons.scm
  * toolbar.scm also works in gtk
  * *.fs updates
* Tue Jul  4 2006 tiwai@suse.de
- updated to version 8.2:
  * fmviolin.clm.
  * changed after-apply-hook to after-apply-controls-hook
  * removed mus-make-error.
  * Walter Zorn's wz_tooltip.js to spruce up the documentation
* Wed May 17 2006 tiwai@suse.de
- updated to version 8.1:
  * many new scm and pd files
  * improved alsa support
  * see HISTORY.Snd for details
- Use gtk2 as GUI.
- Add gsl support.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 tiwai@suse.de
- updated to version 7.18.
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Tue Apr 19 2005 ro@suse.de
- added missing sentinel
* Mon Feb 14 2005 tiwai@suse.de
- updated to version 7.10.
* Mon Jan 24 2005 tiwai@suse.de
- update dto version 7.9
- use fftw3, libsamplerate.
* Wed Apr 28 2004 ro@suse.de
- added -fno-strict-aliasing
* Sun Mar 21 2004 ro@suse.de
- removed *~ backup files
* Fri Feb 27 2004 tiwai@suse.de
- updated to version 7.2
- support jack and opengl.
- built with the standard guile.
- build as non-root.
- added desktop file and icon.
* Fri Nov 21 2003 ro@suse.de
- compile with -DALSA_PCM_OLD_HW_PARAMS_API
* Fri Nov  7 2003 ro@suse.de
- fix for current autoconf
* Mon Aug 25 2003 tiwai@suse.de
- updated to version 6.11.
* Thu Jun 12 2003 kukuk@suse.de
- Add missing directories to filelist
* Mon Feb  3 2003 tiwai@suse.de
- removed -mminimal-toc for ppc64 (bug #23266).
* Fri Jan 17 2003 tiwai@suse.de
- updated to version 6.5.
- renamed patches to avoid the file name confliction.
* Tue Nov 26 2002 tiwai@suse.de
- updated to version 6.3.
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xshared> to <x-devel-packages>
- changed neededforbuild <xdevel> to <>
* Tue Sep 24 2002 tiwai@suse.de
- updated to snd-6.1.
  regenerated no-gtk patch.
* Mon Aug  5 2002 tiwai@suse.de
- build guile-1.5 together with snd.  guile-1.4.x is incompatible
  and the scm files provided by snd don't work with it.
  snd is linked statically with libguile.
- provides dlp's version of snd together with a start-up script.
- provides tutorial files.
* Tue Jul 16 2002 tiwai@suse.de
- updated to snd-5.12.
- build snd with motif instead of gtk.
  the gtk version is unlikely developed by the author...
* Sat Jun 29 2002 olh@suse.de
- build with -mminimal-toc on ppc64
* Wed Apr 10 2002 tiwai@suse.de
- updated to snd-5.8.
- don't rebuild configure script;
  now snd can use gtk2, which is not supported with guile-gtk.
* Tue Jan 15 2002 tiwai@suse.de
- updated to snd-5.6.
* Tue Dec  4 2001 tiwai@suse.de
- updated to snd-5.5.
  now built with ALSA 0.9.0.
* Mon Nov 12 2001 tiwai@suse.de
- updated to snd-5.4.
* Fri Oct  5 2001 tiwai@suse.de
- updated to snd-5.3.
* Tue Sep  4 2001 tiwai@suse.de
- updated to snd-5.2.
  built from the 5.2 tarball.
* Mon Aug 13 2001 tiwai@suse.de
- updated to snd-5.1 from cvs 20010813.
* Tue Jul 10 2001 tiwai@suse.de
- updated to snd-5.
* Mon Mar 26 2001 tiwai@suse.de
- Updated to snd-4.12.
* Thu Mar  8 2001 tiwai@suse.de
- Fixed compile on ia64.
* Mon Feb  5 2001 tiwai@suse.de
- Updated to snd-4.10.
* Wed Dec 13 2000 tiwai@suse.de
- Updated to snd-4.8.
* Tue Nov 28 2000 tiwai@suse.de
- Compile snd utilities.
- Fixed files list.
- Added guile-gtk in neededforbuild.
- Support ALSA also on ppc.
* Thu Nov  2 2000 tiwai@suse.de
- Updated to snd-4.7.
- Fixed spec file for long package-name support.
* Tue Sep 26 2000 tiwai@suse.de
- Update to snd-4.6.
- Compile with gtk instead of lesstif.
* Fri Sep  1 2000 tiwai@suse.de
- Compile fix for alpha.
* Mon Jul 24 2000 tiwai@suse.de
- snd ver.4 - compiled with motif and ALSA (for i386) and OSS (for PPC)
